@@ -21,9 +21,12 @@ ok(1); # If we made it this far, we're ok.
 print "Trying to process template with tt...    ";
 my $out = "";
 open F, "test/test1.out" or die $!;
-my $ref = join "", (<F>);
+my $ref = join('',(<F>));
 close F;
 $tt->process("test/Templates/one",undef,\$out) || die $tt->error()."\n";
+#open F, ">test/test1.out" or die $!;
+#print F $out;
+#close F;
 ok(2);
 print "Comparing output with what's expected... ";
 die "Did not produce the expected output!" unless $out eq $ref;
